==> GGtools_2.0.2.zip: GGtools/doc/GGoverview2008.R <==
###################################################
### chunk number 1: doini
###################################################
library(GGtools)
data(hmceuB36.2021)
hmceuB36.2021


###################################################
### chunk number 2: lkex
###################################################
exprs(hmceuB36.2021)[1:5,1:5]


###################################################
### chunk number 3: lksn
###################################################
smList(hmceuB36.2021)


###################################################
### chunk number 4: lksn2
###################################################
rawSNP(hmceuB36.2021, 20)[1:5,1:5]


###################################################
### chunk number 5: lksn3
###################################################
as(smList(hmceuB36.2021)[["20"]][1:5,1:5], "character")


###################################################
### chunk number 6: dot
###################################################
g1 = gwSnpScreen(genesym("CPNE1"), hmceuB36.2021, chrnum(20))
class(g1)
g1


###################################################
### chunk number 7: lkdo
###################################################
plot(g1)


###################################################
### chunk number 8: lkklk
###################################################
tt = topSnps(g1)
tt


###################################################
### chunk number 9: lks
###################################################
plot_EvG( genesym("CPNE1"), rsNum(rownames(tt)[1]), hmceuB36.2021 )


###################################################
### chunk number 10: getddd
###################################################
library(GGdata)
if (!exists("hmceuB36")) data(hmceuB36)


###################################################
### chunk number 11: dodo
###################################################
ONWIN = FALSE
ONWIN = (Sys.info()["sysname"] == "Windows") 
if (!ONWIN) {
rr = gwSnpScreen(genesym("RPS26"), hmceuB36)
rrt = topSnps(rr)
rrt[[12]]
}


###################################################
### chunk number 12: dodwg
###################################################
if (ONWIN) { rr = 1 }; plot(rr)


###################################################
### chunk number 13: lkpd
###################################################
names(pData(hmceuB36))


###################################################
### chunk number 14: doddss
###################################################
sessionInfo()

==> GGtools_3.2.0.zip: GGtools/doc/GGoverview2008.R <==
###################################################
### chunk number 1: doini
###################################################
library(GGtools)
data(hmceuB36.2021)
hmceuB36.2021


###################################################
### chunk number 2: lkex
###################################################
exprs(hmceuB36.2021)[1:5,1:5]


###################################################
### chunk number 3: lksn
###################################################
smList(hmceuB36.2021)
class(smList(hmceuB36.2021)[["20"]])


###################################################
### chunk number 4: lkr
###################################################
schunk = smList(hmceuB36.2021)[["20"]]
schunk@.Data[1:4,1:4]


###################################################
### chunk number 5: lkr2
###################################################
as(schunk[1:4,1:4], "character")


###################################################
### chunk number 6: dod
###################################################
pd = pData(hmceuB36.2021)
hmFou = hmceuB36.2021[, which(pd$mothid == 0 & pd$fathid == 0)]
f1 = gwSnpTests(genesym("CPNE1")~male, hmFou, chrnum(20))


###################################################
### chunk number 7: lkc
###################################################
schunk["NA06985", "rs4814683"]


###################################################
### chunk number 8: gets
###################################################
library(SNPlocs.Hsapiens.dbSNP.20071016)
s20 = getSNPlocs("chr20")
s20[ s20[,1] == 4814683, ]


###################################################
### chunk number 9: dotr
###################################################
library(Biostrings)
IUPAC_CODE_MAP
